@@ -14,6 +14,7 @@ from pylav.config_migrations.m0880 import run_migration_0880
 from pylav.config_migrations.m0920 import run_migration_0920
 from pylav.config_migrations.m01050 import run_migration_01050
 from pylav.config_migrations.m01130 import run_migration_01130
+from pylav.config_migrations.m01180 import run_migration_01180
 from pylav.config_migrations.set_current_version import set_current_version
 from pylav.config_migrations.update_plugins import update_plugins
 
@@ -44,5 +45,6 @@ class UpdateSchemaManager:
         await run_migration_0920(self._client, current_version)
         await run_migration_01050(self._client, current_version)
         await run_migration_01130(self._client, current_version)
+        await run_migration_01180(self._client, current_version)
         await set_current_version(self._client)
         await update_plugins(self._client)
